@@ -2,7 +2,7 @@
   FILE: icalcomponent.c
   CREATOR: eric 28 April 1999
   
-  $Id: icalcomponent.c,v 1.28 2005/09/20 02:20:54 haip Exp $
+  $Id: icalcomponent.c 604 2007-05-25 14:05:33Z rburton $
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
 
@@ -1240,7 +1240,7 @@ struct icalcomponent_kind_map {
 
   
 
-static struct icalcomponent_kind_map component_map[] = 
+static const struct icalcomponent_kind_map component_map[] = 
 {
     { ICAL_VEVENT_COMPONENT, "VEVENT" },
     { ICAL_VTODO_COMPONENT, "VTODO" },
