@@ -3,7 +3,7 @@
   FILE: icalenum.c
   CREATOR: eric 29 April 1999
   
-  $Id: icalenums.c 393 2003-10-21 18:28:34Z ettore $
+  $Id: icalenums.c 604 2007-05-25 14:05:33Z rburton $
 
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -38,7 +38,7 @@
 
 /*** @brief Allowed request status values
  */
-static struct {
+static const struct {
 	 enum icalrequeststatus kind;
 	int major;
 	int minor;
