@@ -2,7 +2,7 @@
   FILE: icalvcal.c
   CREATOR: eric 25 May 00
   
-  $Id: icalvcal.c,v 1.8 2005/08/24 02:32:23 zucchi Exp $
+  $Id: icalvcal.c 604 2007-05-25 14:05:33Z rburton $
 
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -80,7 +80,7 @@ struct conversion_table_struct {
 	int icaltype;
 };
 
-struct conversion_table_struct conversion_table[];
+static const struct conversion_table_struct conversion_table[];
 void* dc_prop(int icaltype, VObject *object, icalcomponent *comp,
 	      icalvcal_defaults *defaults);
 
@@ -655,6 +655,10 @@ static int get_alarm_properties (icalcomponent *comp, VObject *object,
 	    url = icalattach_get_url (attach);
 
 	    /* Check for Gnome Calendar, which will just save a pathname. */
+	    /* FIXME: This is broken on Win32. No idea whether this code
+	     * ever is invoked in the context of Evolution, though.
+	     * --tml@novell.com
+	     */
 	    if (url && url[0] == '/') {
 		int len;
 		char *new_url;
@@ -1417,7 +1421,7 @@ of the vcal properties in it. I didn't feel like re-doing the entire
 table, so you'll have to find the missing properties the hard way --
 the code will assert */
 
-struct conversion_table_struct conversion_table[] = 
+static const struct conversion_table_struct conversion_table[] = 
 {
 {VCCalProp,            COMPONENT, comp,         ICAL_VCALENDAR_COMPONENT},
 {VCTodoProp,           COMPONENT, comp,         ICAL_VTODO_COMPONENT},
