@@ -156,11 +156,12 @@ check_header (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMess
 		if (g_ascii_strcasecmp(name, "x-camel-mlist") == 0) {
 			const char *list = camel_message_info_mlist(fms->info);
 
-			if (list)
+			if (list) {
 				for (i=1; i<argc && !matched; i++) {
 					if (argv[i]->type == ESEXP_RES_STRING)
 						matched = camel_search_header_match(list, argv[i]->value.string, how, CAMEL_SEARCH_TYPE_MLIST, NULL);
 				}
+			}
 		} else {
 			CamelMimeMessage *message = camel_filter_search_get_message (fms, f);
 			struct _camel_header_raw *header;
@@ -532,7 +533,6 @@ child_watch (GPid     pid,
 	g_spawn_close_pid (pid);
 
 	child_watch_data->child_status = status;
-
 	g_main_loop_quit (child_watch_data->loop);
 }
 
@@ -548,6 +548,7 @@ run_command (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessa
 	GPtrArray *args;
 	child_watch_data_t child_watch_data;
 	GSource *source;
+	GMainContext *context;
 	
 	if (argc < 1 || argv[0]->value.string[0] == '\0')
 		return 0;
@@ -589,7 +590,9 @@ run_command (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessa
 	camel_stream_flush (stream);
 	camel_object_unref (stream);
 	
-	child_watch_data.loop = g_main_loop_new (g_main_context_new (), FALSE);
+	context = g_main_context_new ();
+	child_watch_data.loop = g_main_loop_new (context, FALSE);
+	g_main_context_unref (context);
 
 	source = g_child_watch_source_new (child_pid);
 	g_source_set_callback (source, (GSourceFunc) child_watch, &child_watch_data, NULL);
