@@ -30,28 +30,31 @@
 #endif
 
 #include <sys/types.h>
-#include <dirent.h>
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
 
+#include <glib.h>
+#include <glib/gstdio.h>
 #include <gmodule.h>
 
-#include "camel-provider.h"
+#include "libedataserver/e-msgport.h"
+
 #include "camel-exception.h"
+#include "camel-i18n.h"
+#include "camel-provider.h"
 #include "camel-string-utils.h"
 #include "camel-vee-store.h"
-#include "libedataserver/e-msgport.h"
-#include "camel-i18n.h"
+#include "camel-private.h"
 
 /* table of CamelProviderModule's */
 static GHashTable *module_table;
 /* table of CamelProvider's */
 static GHashTable *provider_table;
-static EMutex *provider_lock;
+static GStaticRecMutex provider_lock = G_STATIC_REC_MUTEX_INIT;
 
-#define LOCK() e_mutex_lock(provider_lock);
-#define UNLOCK() e_mutex_unlock(provider_lock);
+#define LOCK()		(g_static_rec_mutex_lock(&provider_lock))
+#define UNLOCK()	(g_static_rec_mutex_unlock(&provider_lock))
 
 /* The vfolder provider is always available */
 static CamelProvider vee_provider = {
@@ -73,7 +76,6 @@ static pthread_once_t setup_once = PTHREAD_ONCE_INIT;
 static void
 provider_setup(void)
 {
-	provider_lock = e_mutex_new(E_MUTEX_REC);
 	module_table = g_hash_table_new(camel_strcase_hash, camel_strcase_equal);
 	provider_table = g_hash_table_new(camel_strcase_hash, camel_strcase_equal);
 
@@ -100,8 +102,8 @@ provider_setup(void)
 void
 camel_provider_init (void)
 {
-	DIR *dir;
-	struct dirent *d;
+	GDir *dir;
+	const char *entry;
 	char *p, *name, buf[80];
 	CamelProviderModule *m;
 	static int loaded = 0;
@@ -113,22 +115,22 @@ camel_provider_init (void)
 
 	loaded = 1;
 
-	dir = opendir (CAMEL_PROVIDERDIR);
+	dir = g_dir_open (CAMEL_PROVIDERDIR, 0, NULL);
 	if (!dir) {
 		g_warning("Could not open camel provider directory (%s): %s",
 			  CAMEL_PROVIDERDIR, g_strerror (errno));
 		return;
 	}
 	
-	while ((d = readdir (dir))) {
+	while ((entry = g_dir_read_name (dir))) {
 		FILE *fp;
 		
-		p = strrchr (d->d_name, '.');
+		p = strrchr (entry, '.');
 		if (!p || strcmp (p, ".urls") != 0)
 			continue;
 		
-		name = g_strdup_printf ("%s/%s", CAMEL_PROVIDERDIR, d->d_name);
-		fp = fopen (name, "r");
+		name = g_strdup_printf ("%s/%s", CAMEL_PROVIDERDIR, entry);
+		fp = g_fopen (name, "r");
 		if (!fp) {
 			g_warning ("Could not read provider info file %s: %s",
 				   name, g_strerror (errno));
@@ -137,7 +139,7 @@ camel_provider_init (void)
 		}
 		
 		p = strrchr (name, '.');
-		strcpy (p, ".so");
+		strcpy (p, "." G_MODULE_SUFFIX);
 
 		m = g_malloc0(sizeof(*m));
 		m->path = name;
@@ -159,7 +161,7 @@ camel_provider_init (void)
 		fclose (fp);
 	}
 
-	closedir (dir);
+	g_dir_close (dir);
 }
 
 /**
@@ -188,7 +190,7 @@ camel_provider_load(const char *path, CamelException *ex)
 		return;
 	}
 
-	module = g_module_open (path, 0);
+	module = g_module_open (path, G_MODULE_BIND_LAZY);
 	if (!module) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Could not load %s: %s"),
