@@ -6,7 +6,7 @@
  *    Dan Winship <danw@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,7 +14,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -37,7 +37,20 @@
 				 CAMEL_MESSAGE_FLAGGED | \
 				 CAMEL_MESSAGE_SEEN)
 
-#define CAMEL_IMAP_MESSAGE_RECENT (1 << 17)
+enum {
+	CAMEL_IMAP_MESSAGE_RECENT = 1<<17,
+
+	/* We store the label in flags too, to ease processing.
+	   TODO: Move this to camel-folder-summary, BUT don't use
+	   1 bit per label, instead use a bitfield of 3 bits */
+
+	CAMEL_IMAP_MESSAGE_LABEL1 = 1<<18,
+	CAMEL_IMAP_MESSAGE_LABEL2 = 1<<19,
+	CAMEL_IMAP_MESSAGE_LABEL3 = 1<<20,
+	CAMEL_IMAP_MESSAGE_LABEL4 = 1<<21,
+	CAMEL_IMAP_MESSAGE_LABEL5 = 1<<22,
+	CAMEL_IMAP_MESSAGE_LABEL_MASK = 31<<18
+};
 
 typedef struct _CamelImapSummaryClass CamelImapSummaryClass;
 
